/*
 * Copyright 2012-2017 Amazon Technologies, Inc.
 * 
 * Licensed under the Amazon Software License (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at:
 * 
 * http://aws.amazon.com/asl
 * 
 * This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES
 * OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and
 * limitations under the License.
 */ 



package com.amazonaws.mturk.cmd.test;

import junit.textui.TestRunner;

import com.amazonaws.mturk.cmd.LoadHITs;
import com.amazonaws.mturk.requester.HIT;

public class TestLoadHITs extends TestBase {

  public static void main(String[] args) {
    // Change the output to log to a file   
    TestRunner.run(TestLoadHITs.class);
  }

  public TestLoadHITs(String arg0) {
    super(arg0);
  }

  public void testLoadHITs() throws Exception {
    // Change the output to log to a file
    LoadHITs cmd = new LoadHITs();
    cmd.setSandBoxMode();

    HIT[] hits = cmd.loadHITs(inputFile, questionFile, 
        propertiesFile, cmd.MAX_HITS_UNLIMITED);

    assertNotNull(hits);
    assertTrue(hits.length > 0);
  }

  public void testLoadHITsMaxHITs() throws Exception {
    LoadHITs cmd = new LoadHITs();
    cmd.setSandBoxMode();

    HIT[] hits = cmd.loadHITs(inputFile, questionFile, 
        propertiesFile, 1);  

    assertTrue(hits.length == 1);
  }

  public void testLoadHITsMaxHITsZero() throws Exception {
    LoadHITs cmd = new LoadHITs();
    cmd.setSandBoxMode();

    HIT [] hits = cmd.loadHITs(inputFile, questionFile, 
        propertiesFile, 0);  

    assertTrue(hits.length == 0);
  }

  public void testLoadHITsWrongInputFile() throws Exception {
    LoadHITs cmd = new LoadHITs();

    try {
      cmd.loadHITs("wrongfile", questionFile, 
          propertiesFile, 1);
    } catch (Exception e) {
      // expected
    }
  }

  public void testLoadHITsWrongQuestionFile() throws Exception {
    LoadHITs cmd = new LoadHITs();
    cmd.setSandBoxMode();

    try {
      cmd.loadHITs(inputFile, "wrongfile", 
          propertiesFile, 1);
    } catch (Exception e) {
      // expected
    }
  }

  public void testLoadHITsWrongPropertiesFile() throws Exception {
    LoadHITs cmd = new LoadHITs();
    cmd.setSandBoxMode();

    try {
      cmd.loadHITs(inputFile, questionFile, 
          "wrongfile", 1);  
    } catch (Exception e) {
      // expected
    }
  }

  public void testLoadHITsNullLabel() throws Exception {
    LoadHITs cmd = new LoadHITs();
    cmd.setSandBoxMode();

    HIT[] hits = cmd.loadHITs(inputFile, questionFile, 
        propertiesFile, 1);  

    assertNotNull(hits);
    assertTrue(hits.length == 1);
  }
}
